{% extends "bases/unicms_unical.html" %}

{% load i18n %}
{% load static %}

<!-- load custom template tags -->
{% load unicms_carousels %}
{% load unicms_contexts %}
{% load unicms_menus %}
{% load unicms_templates %}
{% load unicms_pages %}
{% load unicms_publications %}


{% block header_center_logo %}
    <div class="d-none d-lg-flex col-lg-12 px-0">
        <image src="{% static 'images/unical_logo_bullet_white.svg' %}" />
        {% block header_center_logo_side %}
        {% endblock header_center_logo_side %}
    </div>
{% endblock header_center_logo %}

{% block unical_mobile_logo %}
    <div class="row">
        <div class="col-2 col-md-1" style="margin: auto 0">
            <image src="{% static 'images/unical_logo_bullet_white.svg' %}" width="100%"/>
        </div>
        <div class="col-10 col-md-11">
            {% block header_slim_mobile_org_name_side %}
            {% endblock header_slim_mobile_org_name_side %}
        </div>
    </div>
{% endblock unical_mobile_logo %}
